Learn R Programming

wql (version 1.0.2)

sfbay: San Francisco Bay water quality data

Description

Selected observations and variables from U.S. Geological Survey water quality stations in south San Francisco Bay. Data include CTD and nutrient measurements.

Arguments

Format

sfbay is a data frame with 23207 observations (rows) of 12 variables (columns):

[, 1]datedate
[, 2]timetime
[, 3]stnstation code
[, 4]depthmeasurement depth
[, 5]chlchlorophyll a
[, 6]dox.pctdissolved oxygen
[, 7]spmsuspended particulate matter
[, 8]extextinction coefficient
[, 9]salsalinity
[, 10]tempwater temperature
[, 11]noxnitrate + nitrite
[, 12]nhxammonium

sfbayStns is a data frame with 16 observations of 6 variables:

[, 1]sitestation code
[, 2]descriptionstation description
[, 3]latlatitude
[, 4]longlongitude
[, 5]depthMaxmaximum depth, in m
[, 6]distFrom36distance from station 36, in km

sfbayVars is a data frame with 7 observations of 3 variables:

[, 1]variablewater quality variable code
[, 2]descriptiondescription
[, 3]unitsmeasurement units

sfbayChla is a time series matrix (380 months x 16 stations) of average 0-5 m chlorophyll a concentrations calculated from the data in sfbay.

Details

The original downloaded dataset was modified by taking a subset of six well-sampled stations and the period 1985--2004. Variable names were also simplified. The data frames sfbayStns and sfbayVars describe the stations and water quality variables in more detail; they were created from information at the same web site. Note that the station numbers in sfbayStns have been prefixed with s to make station codes into legal variable names. sfbayChla was constructed from the entire downloaded sfbay dataset and encompasses the period 1969--2009.

Examples

Run this code

data(sfbay)
str(sfbay)
str(sfbayStns)
str(sfbayVars)
plot(sfbayChla[, 1:10], main = "SF Bay Chl-a")

Run the code above in your browser using DataLab