Learn R Programming

wql (version 1.0.2)

trendHomog: Trend homogeneity test

Description

Tests for homogeneity of seasonal trends using method proposed by van Belle and Hughes (1984). Seasons with insufficient data as defined in mannKen are ignored.

Usage

trendHomog(x)

Value

chisq.trend

"Trend" chi-square.

chisq.homog

"Homogeneous" chi-square.

p.value

For null hypothesis that trends are homogeneous.

n

Number of seasons used.

Arguments

x

A vector time series with frequency > 1

Author

Alan Jassby, James Cloern

References

van Belle, G. and Hughes, J.P. (1984) Nonparametric tests for trend in water quality. Water Resources Research 20, 127-136.

See Also

seaKen

Examples

Run this code

## Apply to a monthly vector time series to test homogeneity
## of seasonal trends.
x <- sfbayChla[, 's27']
trendHomog(x)

Run the code above in your browser using DataLab